package com.audinate.controller;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.audinate.AudinateUtils;
import com.audinate.DanteDapi;
import com.audinate.Pair;
import com.audinate.Util;
import com.audinate.app.IApplication;
import com.audinate.app.IJavaEnvironment;
import com.audinate.app.JavaEnvironment;
import com.audinate.cmm.CmmConfig;
import com.audinate.cmm.CmmInterface;
import com.audinate.cmm.CmmState;
import com.audinate.cmm.ICmmClient;
import com.audinate.cmm.ICmmClientListener;
import com.audinate.cmm.ICmmClients;
import com.audinate.controller.ControllerApplication;
import com.audinate.controller.ControllerConfig;
import com.audinate.controller.ControllerModel;
import com.audinate.controller.DdhController;
import com.audinate.controller.DdhControllerEvent;
import com.audinate.controller.IControllerConstants;
import com.audinate.controller.IControllerModel;
import com.audinate.controller.IDanteControllerVersion;
import com.audinate.controller.LogicModel;
import com.audinate.controller.Preconditions;
import com.audinate.controller.SplashScreen;
import com.audinate.controller.logic.ControllerLogic;
import com.audinate.dante.DeviceUtils;
import com.audinate.dante.IDevice;
import com.audinate.dante.logic.ILogicDevicesController;
import com.audinate.dante.logic.ILogicModel;
import com.audinate.exception.AudinateException;
import com.audinate.gui.app.ISwingApplication;
import com.audinate.gui.controller.ControllerFrame;
import com.audinate.gui.controller.DeviceFrame;
import com.audinate.gui.controller.DeviceFrames;
import com.audinate.gui.controller.MenuFrame;
import com.audinate.gui.controller.MillauLockDialog;
import com.audinate.gui.controller.StaleAudioConnectionsDialog;
import com.audinate.gui.dante.ISwingDevicesController;
import com.audinate.gui.i18n.ILocalisable;
import com.audinate.gui.themes.ThemeSelector;
import com.audinate.gui.themes.ThemedImage;
import com.audinate.gui.util.ImageLibrary;
import com.audinate.gui.util.ScreenUtils;
import com.audinate.model.json.JsonElement;
import com.audinate.model.json.JsonNull;
import com.audinate.model.json.JsonString;
import com.audinate.model.json.JsonUtil;
import com.audinate.net.NetworkInterface;
import com.audinate.presets.legacy.LegacyUtils;
import com.audinate.timer.ISchedulableTimer;
import com.audinate.timer.ISchedulableTimerHandler;
import com.audinate.urlscheme.UrlSchemeHandler;
import com.audinate.util.IObserver;
import com.audinate.util.IdleStateListener;
import com.audinate.util.IdleStateManager;
import com.audinate.util.Log;
import com.audinate.util.ResourceBundleUtils;
import com.audinate.util.SafeEquals;
import com.audinate.util.Version;
import java.awt.Component;
import java.awt.Desktop;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.FontFormatException;
import java.awt.GraphicsEnvironment;
import java.awt.Image;
import java.awt.Rectangle;
import java.awt.Window;
import java.awt.desktop.OpenURIEvent;
import java.awt.desktop.OpenURIHandler;
import java.awt.event.ActionEvent;
import java.awt.event.ComponentListener;
import java.awt.event.WindowListener;
import java.io.File;
import java.io.InputStream;
import java.io.UnsupportedEncodingException;
import java.net.URI;
import java.net.URLDecoder;
import java.net.URLEncoder;
import java.nio.file.Paths;
import java.text.MessageFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Properties;
import java.util.Queue;
import java.util.ResourceBundle;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import java.util.stream.Collectors;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JCheckBox;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;

public class DanteController implements IControllerConstants, ILogicDevicesController, ISwingDevicesController, ICmmClientListener, ISchedulableTimerHandler, ILocalisable {
  private static final String STORE_KEY_URL = "url";
  
  private static final String HELP_ICON_KEY = "OptionPane.questionIcon";
  
  private static final String DIALOG_WARN_VALUE = "warn";
  
  private static final String DIALOG_IGNORE_VALUE = "ignore";
  
  public static final boolean DANTE_CONTROLLER_SHARED_LIBRARY = true;
  
  public static final boolean DEBUG_UI_DEFAULTS = false;
  
  public static final boolean DEBUG_RUN = false;
  
  public static final boolean DEBUG_EXIT = false;
  
  public static final int DANTE_AGENT_RESTARTS = 5;
  
  private static final String DANTE_CONTROLLER_AGENT = "DanteControllerAgent";
  
  private static final String DANTE_ARGO_GATEWAY = "DanteGateway";
  
  private static final String PROP_AGENT_SEARCH_PATH = "dc.agent.path";
  
  private static final String PROP_TRANSLATOR_SEARCH_PATH = "dc.translator.path";
  
  private static final String PROP_PLUGIN_SEARCH_PATH = "dc.plugin.path";
  
  private static final String PROP_DYLIB_SEARCH_PATH = "dc.dylib.path";
  
  private static final int STATE_STOPPED = 0;
  
  private static final int STATE_STOPPING = 1;
  
  private static final int STATE_STARTED = 2;
  
  private static final int STATE_CMM_INIT = 3;
  
  private static final int STATE_STARTING = 4;
  
  private static final Integer SOURCE_URL_HANDLER = Integer.valueOf(0);
  
  private static final Integer SOURCE_PERSISTED = Integer.valueOf(1);
  
  private long mStartTime = System.currentTimeMillis();
  
  private ControllerConfig mConfig = new ControllerConfig();
  
  private ControllerApplication mApplication;
  
  private ControllerLogic mLogic;
  
  private LogicModel mLogicModel;
  
  private ControllerFrame mControllerFrame;
  
  private DeviceFrames mDeviceFrames;
  
  private String mAgentPath;
  
  private String mTranslatorPath;
  
  private Process mAgentProcess;
  
  private Process mTranslatorProcess;
  
  private List<String> mPluginSearchPaths;
  
  private int mAgentRestartCount = 0;
  
  private ICmmClient mCmmClient;
  
  private ICmmClients mCmmClients;
  
  private int mAgentWebserverPort;
  
  private int mAgentWebsocketPort;
  
  private int mAgentRemoteComponentPort = 0;
  
  private NetworkInterface mArgoInterface;
  
  private ResourceBundle mBundle;
  
  private IObserver mCmmClientsObserver = (IObserver)new Object(this);
  
  private IObserver mInterfaceManagerObserver = (IObserver)new Object(this);
  
  private ControllerModel mControllerModel;
  
  private int mState = 0;
  
  private Queue<Pair<URI, Integer>> mPendingUrls = new LinkedList<>();
  
  private static UrlSchemeHandler sHandler;
  
  private ICmmClientListener mCmmListener;
  
  private DdhController mDdhController;
  
  public void initUI(IJavaEnvironment paramIJavaEnvironment) {
    Icon icon1 = UIManager.getIcon("OptionPane.questionIcon");
    try {
      InputStream inputStream1 = getClass().getResourceAsStream("/fonts/DanteSansGUI-Text.otf");
      Font font1 = Font.createFont(0, inputStream1);
      GraphicsEnvironment.getLocalGraphicsEnvironment().registerFont(font1);
      InputStream inputStream2 = getClass().getResourceAsStream("/fonts/DanteSansGUI-Display.otf");
      Font font2 = Font.createFont(0, inputStream2);
      GraphicsEnvironment.getLocalGraphicsEnvironment().registerFont(font2);
    } catch (FontFormatException|java.io.IOException fontFormatException) {
      fontFormatException.printStackTrace();
    } 
    ThemeSelector.init();
    Icon icon2 = UIManager.getIcon("OptionPane.questionIcon");
    if (icon2 == null)
      UIManager.put("OptionPane.questionIcon", icon1); 
  }
  
  public ControllerConfig getConfig() {
    return this.mConfig;
  }
  
  public MenuFrame getControllerFrame() {
    return (MenuFrame)this.mControllerFrame;
  }
  
  public List<DeviceFrame> getDeviceFrames() {
    return this.mDeviceFrames.getAllFrames();
  }
  
  public void createApplication() throws AudinateException {
    this.mApplication = new ControllerApplication(this, this.mStartTime);
    this.mApplication.init();
  }
  
  public void suggestNoValidInterfaces() {
    this.mApplication.suggestNoValidInterfaces((JFrame)this.mControllerFrame);
  }
  
  public void suggestReboot(String paramString) {
    this.mApplication.showRebootWarning((Window)this.mControllerFrame, paramString);
  }
  
  public void createModel() throws AudinateException {
    this.mLogicModel = new LogicModel(this.mApplication);
    this.mLogic = new ControllerLogic(this.mApplication, (ILogicModel)this.mLogicModel, this, this);
    this.mLogicModel.setRouterController(this.mLogic.getRouterController());
    this.mControllerModel = new ControllerModel((IApplication)this.mApplication, this.mApplication.getControllerConfig(), this.mLogicModel.getUnfilteredDevices(), this.mLogicModel.getRtpFlows(), this.mLogicModel);
    this.mConfig.setDomainHandler(this.mLogicModel.getDomainHandler());
  }
  
  public void createView() throws AudinateException {
    this.mDdhController = new DdhController((ISwingApplication)this.mApplication, this.mLogicModel.getDomainHandler());
    ImageLibrary imageLibrary = this.mApplication.getImageLibrary();
    ThemedImage[] arrayOfThemedImage = new ThemedImage[5];
    arrayOfThemedImage[2] = imageLibrary.getImage("ERROR_32");
    arrayOfThemedImage[3] = imageLibrary.getImage("WARNING_32");
    arrayOfThemedImage[4] = imageLibrary.getImage("INFORMATION_32");
    this.mControllerFrame = new ControllerFrame(this.mApplication, this.mLogic.getRouterController(), this.mLogic.getConmonController(), this, this.mLogicModel, this.mLogic.getPolls(), this.mControllerModel.getLatencyScheme(), this.mDdhController, (IControllerModel)this.mControllerModel, arrayOfThemedImage);
    this.mControllerFrame.setLogic(this.mLogic);
    this.mControllerFrame.canAddListeners();
    this.mControllerFrame.createCmmConfigDialog();
    this.mDeviceFrames = new DeviceFrames(this.mApplication, (IControllerModel)this.mControllerModel, this.mLogic, this, this.mLogicModel.getMillauLockClient(), this.mControllerFrame, arrayOfThemedImage);
    this.mDeviceFrames.localise(this.mBundle);
  }
  
  private void startSystem() throws AudinateException {
    IJavaEnvironment iJavaEnvironment = JavaEnvironment.getInstance();
    this.mControllerFrame.pack();
    GraphicsEnvironment graphicsEnvironment = GraphicsEnvironment.getLocalGraphicsEnvironment();
    Rectangle rectangle = graphicsEnvironment.getMaximumWindowBounds();
    Dimension dimension = new Dimension();
    dimension.width = Math.min(rectangle.width, 1400);
    dimension.height = Math.min(rectangle.height, 900);
    this.mControllerFrame.setSize(dimension);
    ScreenUtils.centerOnScreen((Window)this.mControllerFrame, null);
    this.mControllerFrame.setVisible(true);
    this.mApplication.start();
    this.mLogicModel.start();
    this.mLogic.start();
    String str1 = "DanteControllerAgent";
    String str2 = "DanteGateway";
    int i = this.mApplication.getPlatform().getPlatformType();
    if (i == 0) {
      str1 = str1 + ".exe";
      str2 = str2 + ".exe";
    } 
    String str3 = System.getProperty("dc.agent.path");
    if (str3 != null && !"".equals(str3))
      str1 = resolvePath(iJavaEnvironment, str3); 
    String str4 = System.getProperty("dc.translator.path");
    if (str4 != null && !"".equals(str4))
      str2 = resolvePath(iJavaEnvironment, str4) + "/" + resolvePath(iJavaEnvironment, str4); 
    File file1 = new File(str2);
    if (file1.exists() && file1.canExecute()) {
      this.mTranslatorPath = str2;
    } else {
      this.mApplication.getDebugLog().log(4, null, "Argo translator executable not found: " + str2);
    } 
    File file2 = new File(str1);
    if (file2.exists() && file2.canExecute()) {
      this.mAgentPath = str1;
      this.mPluginSearchPaths = new LinkedList<>();
      String str5 = getConfig().getPluginPath();
      if (str5 != null && !str5.isEmpty())
        this.mPluginSearchPaths.add(str5); 
      String str6 = "./plugins";
      String str7 = System.getProperty("dc.plugin.path");
      if (str7 != null)
        str6 = resolvePath(iJavaEnvironment, str7); 
      this.mPluginSearchPaths.add(str6);
    } 
    this.mApplication.getSchedulableTimers().createRelativeTimer(this, 1000L, "checkProcessesRunning");
    this.mCmmClients = this.mLogicModel.getCmmClients();
    this.mCmmClients.addObserver(this.mCmmClientsObserver);
    setCmmClient(this.mCmmClients.getSelectedClient());
    this.mArgoInterface = null;
    this.mApplication.getNetworkInterfaceManager().addObserver(this.mInterfaceManagerObserver);
  }
  
  private static String resolvePath(IJavaEnvironment paramIJavaEnvironment, String paramString) {
    return Paths.get(paramString, new String[0]).toAbsolutePath().normalize().toString();
  }
  
  public void startInGuiThread() {
    SwingUtilities.invokeLater(() -> start());
  }
  
  public void stopInGuiThread() {
    SwingUtilities.invokeLater(() -> stop());
  }
  
  public void start() {
    this.mState = 4;
    try {
      createApplication();
      String[] arrayOfString = this.mApplication.getResourceLocations();
      Image image = ImageLibrary.loadImageHelper("images", "splashscreen.png", arrayOfString).getImage();
      SplashScreen.show(new ImageIcon(image), 5000, () -> {
            try {
              if (this.mApplication.getControllerConfig().isPreloadingBrowser())
                this.mApplication.getBrowserEngine(); 
            } catch (Throwable throwable) {
              throwable.printStackTrace();
              this.mApplication.getDebugLog().logThrowable(4, null, throwable.getMessage(), throwable);
              System.exit(1);
            } 
          }() -> {
            try {
              createModel();
              createView();
              startSystem();
            } catch (Throwable throwable) {
              throwable.printStackTrace();
              this.mApplication.getDebugLog().logThrowable(4, null, throwable.getMessage(), throwable);
              System.exit(1);
            } 
            String str = this.mConfig.getLanguage();
            this.mApplication.getAnalyticsReporter().submitEvent("APPLICATION_LAUNCHED", JsonUtil.toJson(Map.of("languageCfg", (str != null) ? JsonUtil.toJson(str) : (JsonString)JsonNull.VALUE, "language", JsonUtil.toJson(this.mConfig.getStringsBundle().getString("i18n.language.code")))));
            new IdleStateManager((IdleStateListener)new Object(this));
            this.mState = 2;
            this.mCmmListener = (ICmmClientListener)new Object(this);
            this.mCmmClient.addCmmClientListener(this.mCmmListener);
            this.mDdhController.addEventListener(());
            if (this.mApplication.getEncryptedStore().containsKey("url") && this.mPendingUrls.isEmpty()) {
              this.mApplication.getDebugLog().log(6, null, "Scheduling persisted credentials for processing.");
              this.mPendingUrls.add(new Pair(URI.create(this.mApplication.getEncryptedStore().get("url").asString().getValue()), SOURCE_PERSISTED));
            } 
          });
    } catch (Throwable throwable) {
      throwable.printStackTrace();
      this.mApplication.getDebugLog().logThrowable(4, null, throwable.getMessage(), throwable);
      System.exit(1);
    } 
  }
  
  private void setEnabled(boolean paramBoolean) {
    this.mControllerFrame.setEnabled(paramBoolean);
    this.mDeviceFrames.setEnabled(paramBoolean);
  }
  
  public void stop() {
    this.mCmmClient.removeCmmClientListener(this.mCmmListener);
    this.mState = 1;
    this.mDeviceFrames.closeAllFrames();
    this.mControllerFrame.closeFrame();
    this.mControllerFrame.setVisible(false);
    this.mControllerFrame.dispose();
    this.mLogic.stop();
    this.mLogicModel.stop();
    this.mApplication.stop();
    stopAgent();
    this.mApplication.getAnalyticsReporter().submitEvent("APPLICATION_TERMINATED", null);
    this.mApplication.getAnalyticsReporter().waitPending();
    this.mState = 0;
    System.exit(0);
  }
  
  public void showDevice(String paramString) {
    this.mDeviceFrames.getFrame(paramString);
  }
  
  public void showDeviceComponent(String paramString, int paramInt1, int paramInt2) {
    DeviceFrame deviceFrame = this.mDeviceFrames.getFrame(paramString);
    deviceFrame.showComponent(paramInt1, paramInt2, -1);
  }
  
  public void showDeviceComponent(String paramString, int paramInt1, int paramInt2, int paramInt3) {
    DeviceFrame deviceFrame = this.mDeviceFrames.getFrame(paramString);
    deviceFrame.showComponent(paramInt1, paramInt2, paramInt3);
  }
  
  public void showDeviceStat(String paramString, int paramInt1, int paramInt2) {
    DeviceFrame deviceFrame = this.mDeviceFrames.getFrame(paramString);
    deviceFrame.showStat(paramInt1, paramInt2);
  }
  
  public void chooseInterfaces() {
    this.mControllerFrame.chooseInterfaces();
  }
  
  public void suggestInvalidInterfaceConfiguration() {
    this.mControllerFrame.suggestInvalidInterfaceConfiguration();
  }
  
  public static void dumpProperties() {
    System.err.println("Properties:");
    Properties properties = System.getProperties();
    for (String str : properties.keySet()) {
      Object object = properties.get(str);
      System.err.println("" + str + "=" + str);
    } 
  }
  
  public static void main(String[] paramArrayOfString) throws Exception {
    com.audinate.controller.DanteController danteController = createController(paramArrayOfString);
    SwingUtilities.invokeAndWait(() -> paramDanteController.start());
  }
  
  public static com.audinate.controller.DanteController createController(String[] paramArrayOfString) throws Exception {
    if (!Preconditions.checkPreconditions())
      System.exit(0); 
    IJavaEnvironment iJavaEnvironment = JavaEnvironment.getInstance();
    Util.suppressLibrary();
    DanteDapi.suppressLibrary();
    try {
      if (iJavaEnvironment.isOsx()) {
        String str1 = "./libDanteController.dylib";
        String str2 = System.getProperty("dc.dylib.path");
        if (str2 != null)
          str1 = resolvePath(iJavaEnvironment, str2); 
        System.out.println("lib: " + str1);
        File file = new File(str1);
        if (file.exists())
          System.load(str1); 
      } else {
        System.loadLibrary("DanteController");
      } 
    } catch (Exception exception) {
      System.out.println("Exception.Msg: " + exception.toString());
      exception.printStackTrace();
      System.exit(0);
    } catch (Error error) {
      System.out.println("Error.Msg: " + error.toString());
      error.printStackTrace();
      System.exit(0);
    } 
    AudinateUtils.verifyEnums();
    if (paramArrayOfString.length > 0 && paramArrayOfString[0].equalsIgnoreCase("-convert")) {
      String[] arrayOfString = new String[paramArrayOfString.length - 1];
      System.arraycopy(paramArrayOfString, 1, arrayOfString, 0, arrayOfString.length);
      LegacyUtils.main(arrayOfString);
      System.exit(0);
    } 
    com.audinate.controller.DanteController danteController = new com.audinate.controller.DanteController();
    OpenURIHandler openURIHandler = paramOpenURIEvent -> SwingUtilities.invokeLater(());
    Desktop desktop = Desktop.getDesktop();
    if (desktop.isSupported(Desktop.Action.APP_OPEN_URI)) {
      desktop.setOpenURIHandler(openURIHandler);
    } else {
      sHandler = new UrlSchemeHandler("dantecontroller");
      if (paramArrayOfString.length > 1 && "--open-url".equalsIgnoreCase(paramArrayOfString[0]))
        if (sHandler.submitUrl(paramArrayOfString[1])) {
          openURIHandler.openURI(new OpenURIEvent(sHandler.getLastUrl()));
          String[] arrayOfString = new String[paramArrayOfString.length - 2];
          System.arraycopy(paramArrayOfString, 2, arrayOfString, 0, arrayOfString.length);
          paramArrayOfString = arrayOfString;
        } else {
          System.exit(0);
        }  
      sHandler.startListening(openURIHandler);
    } 
    danteController.mConfig.setAutoThemeFn(() -> paramDanteController.mApplication.getPlatform().isDarkModeEnabled() ? "dark" : "light");
    danteController.mConfig.parseArgs(paramArrayOfString);
    if (danteController.mConfig.getStartDelay() > 0) {
      System.err.println("Starting start delay");
      Thread.sleep((danteController.mConfig.getStartDelay() * 1000));
      System.err.println("Finished start delay");
    } 
    danteController.initUI(iJavaEnvironment);
    return danteController;
  }
  
  private void handleUrl(URI paramURI) {
    this.mPendingUrls.add(new Pair(paramURI, SOURCE_URL_HANDLER));
    if (this.mState == 3)
      processUrls(); 
  }
  
  private void processUrls() {
    if (!this.mPendingUrls.isEmpty()) {
      this.mControllerFrame.setState(0);
      this.mControllerFrame.setAlwaysOnTop(true);
      this.mControllerFrame.setAlwaysOnTop(false);
    } 
    while (!this.mPendingUrls.isEmpty()) {
      Pair pair = this.mPendingUrls.remove();
      processUrl((URI)pair.getFirst(), (Integer)pair.getSecond());
    } 
  }
  
  private void processUrl(URI paramURI, Integer paramInteger) {
    Pattern pattern = Pattern.compile("^dantecontroller:(?:(?:([^:@]*):?([^:@]*))@)?((?:[^?#\\/]*\\/)*[^?#\\/]+)\\/?(?:\\?((?:[^&#]*&)*(?:[^&#]*)))?(?:\\#((?:[^&#]*)))?$");
    Matcher matcher = pattern.matcher(paramURI.toString());
    if (matcher.matches()) {
      String str1 = urlDecodeSafe(matcher.group(3));
      String str2 = matcher.group(4);
      Map<String, String> map = (str2 != null) ? (Map)Arrays.<String>asList(str2.split("&")).stream().map(paramString -> paramString.split("=")).collect(Collectors.toMap(paramArrayOfString -> (paramArrayOfString.length > 0) ? urlDecodeSafe(paramArrayOfString[0]).toLowerCase() : null, paramArrayOfString -> (paramArrayOfString.length > 1) ? urlDecodeSafe(paramArrayOfString[1]) : null)) : Collections.emptyMap();
      this.mApplication.getDebugLog().log(8, null, "Url Path: " + str1);
      this.mApplication.getDebugLog().log(8, null, "Url Query Params: " + map);
      if (map.containsKey("minversion")) {
        Version version = new Version((String)map.get("minversion"), 3);
        if (SafeEquals.safeCompare((Comparable)version, IDanteControllerVersion.VERSION) > 0) {
          this.mApplication.getDialogs().showError((Window)this.mControllerFrame, MessageFormat.format(ResourceBundleUtils.getString(this.mBundle, "errors.applicationUrlNotSupported"), new Object[] { version }));
          return;
        } 
      } 
      boolean bool = false;
      if (map.containsKey("host") && map.containsKey("port")) {
        String str3 = (String)map.get("host");
        int i = Integer.parseInt((String)map.get("port"));
        String str4 = (String)map.get("user");
        if (map.containsKey("user") && map.containsKey("pass")) {
          this.mControllerFrame.initDomainHandler(str4, str3, String.valueOf(i));
          this.mDdhController.setSourceWindow((Window)this.mControllerFrame);
          this.mDdhController.setDomainManagerAddr(str3, i);
          bool = true;
          this.mDdhController.loginWithUserPass(str4, (String)map.get("pass"), (String)map.get("domain"), paramInteger -> {
                if (paramInteger.intValue() == 0)
                  processPath(paramURI, paramString, paramMap); 
              });
        } else if (map.containsKey("token")) {
          this.mControllerFrame.initDomainHandler(str4, str3, String.valueOf(i));
          this.mDdhController.setSourceWindow((Window)this.mControllerFrame);
          this.mDdhController.setDomainManagerAddr(str3, i);
          boolean bool1 = (map.containsKey("persist") && Boolean.parseBoolean((String)map.get("persist"))) ? true : false;
          bool = true;
          boolean bool2 = (bool1 || SOURCE_PERSISTED.equals(paramInteger)) ? true : false;
          this.mDdhController.loginWithToken(str4, (String)map.get("token"), (String)map.get("domain"), bool2, paramInteger2 -> {
                if (paramInteger2.intValue() == 0) {
                  if (paramBoolean && !SOURCE_PERSISTED.equals(paramInteger1)) {
                    this.mApplication.getDebugLog().log(6, null, "Processed application url with persist - persisting credentials.");
                    this.mApplication.getEncryptedStore().put("url", (JsonElement)JsonUtil.toJson(buildCustomUrl("default", pick(paramMap, new String[] { "host", "port", "user", "token" }))));
                  } 
                  processPath(paramURI, paramString, paramMap);
                } else if (SOURCE_PERSISTED.equals(paramInteger1)) {
                  ArrayList<String> arrayList = new ArrayList();
                  boolean bool = false;
                  switch (paramInteger2.intValue()) {
                    case 42:
                      arrayList.add(ResourceBundleUtils.getString(this.mBundle, "domainHandler.errors.notConnectedMaybeBadToken"));
                      bool = true;
                      break;
                    default:
                      arrayList.add(ResourceBundleUtils.getString(this.mBundle, "domainHandler.errors.couldNotRestoreLogin"));
                      arrayList.add("<em>" + this.mDdhController.getErrorString(paramInteger2.intValue()) + "</em>");
                      arrayList.add(ResourceBundleUtils.getString(this.mBundle, "domainHandler.confirmClearPersistedCredentials"));
                      break;
                  } 
                  String str = "<HTML>" + (String)arrayList.stream().collect(Collectors.joining("<br/><br/>")) + "</HTML>";
                  if (!bool) {
                    if (!this.mApplication.getDialogs().queryYesNo((Window)this.mControllerFrame, this.mControllerFrame.getTitle(), str)) {
                      this.mApplication.getDebugLog().log(4, null, "Removing persisted credentials after failed login..");
                      this.mApplication.getEncryptedStore().remove("url");
                    } 
                  } else {
                    this.mApplication.getDialogs().showMessage((Window)this.mControllerFrame, str);
                    this.mApplication.getDebugLog().log(4, null, "Removing persisted credentials due to likely expiry.");
                    this.mApplication.getEncryptedStore().remove("url");
                  } 
                } else {
                  this.mDdhController.showError((Window)this.mControllerFrame, paramInteger2.intValue());
                } 
              });
        } 
      } else if (map.containsKey("domain")) {
        this.mControllerFrame.initDomainHandler(null, null, null);
        this.mDdhController.setActiveDomainByName((String)map.get("domain"));
      } 
      if (!bool) {
        processPath(paramURI, str1, map);
      } else if (!SOURCE_PERSISTED.equals(paramInteger) && this.mApplication.getEncryptedStore().containsKey("url")) {
        this.mApplication.getDebugLog().log(6, null, "Processed new application url, removing existing persisted credentials.");
        this.mApplication.getEncryptedStore().remove("url");
      } 
    } 
  }
  
  @SafeVarargs
  private <K, V> Map<K, V> pick(Map<K, V> paramMap, K... paramVarArgs) {
    HashMap<Object, Object> hashMap = new HashMap<>();
    hashMap.putAll(paramMap);
    hashMap.keySet().retainAll(Arrays.asList((Object[])paramVarArgs));
    return (Map)hashMap;
  }
  
  private String buildCustomUrl(String paramString, Map<String, String> paramMap) {
    StringBuilder stringBuilder = new StringBuilder();
    stringBuilder.append("dantecontroller:");
    try {
      stringBuilder.append(URLEncoder.encode(paramString, "UTF-8"));
      if (!paramMap.isEmpty()) {
        stringBuilder.append('?');
        stringBuilder.append(paramMap.entrySet().stream().map(paramEntry -> {
                try {
                  return URLEncoder.encode((String)paramEntry.getKey(), "UTF-8") + "=" + URLEncoder.encode((String)paramEntry.getKey(), "UTF-8");
                } catch (UnsupportedEncodingException unsupportedEncodingException) {
                  unsupportedEncodingException.printStackTrace();
                  return "";
                } 
              }).collect(Collectors.joining("&")));
      } 
    } catch (UnsupportedEncodingException unsupportedEncodingException) {
      unsupportedEncodingException.printStackTrace();
    } 
    return stringBuilder.toString();
  }
  
  private boolean processPath(URI paramURI, String paramString, Map<String, String> paramMap) {
    if ("routing".equals(paramString)) {
      this.mControllerFrame.setActiveTab(0);
      return true;
    } 
    if ("devices".equals(paramString)) {
      this.mControllerFrame.setActiveTab(1);
      return true;
    } 
    if ("devices-clocking".equals(paramString)) {
      this.mControllerFrame.setActiveTab(2);
      return true;
    } 
    if ("devices-network".equals(paramString)) {
      this.mControllerFrame.setActiveTab(3);
      return true;
    } 
    if ("events".equals(paramString)) {
      this.mControllerFrame.setActiveTab(4);
      return true;
    } 
    if ("activator".equals(paramString)) {
      this.mControllerFrame.triggerActivatorAction();
      return true;
    } 
    if ("updater".equals(paramString)) {
      this.mControllerFrame.triggerUpdaterAction();
      return true;
    } 
    if ("set-domain-manager".equals(paramString)) {
      this.mControllerFrame.openEnrolConfigDialog(paramMap.get("enroldomain"));
      return true;
    } 
    if ("login-domain-manager".equals(paramString)) {
      this.mControllerFrame.openDomainHandler(null, null, null);
      return true;
    } 
    if ("default".equals(paramString))
      return true; 
    this.mApplication.getDebugLog().log(3, null, "Unhandled url: \"" + paramURI.toString() + "\"");
    return false;
  }
  
  private String urlDecodeSafe(String paramString) {
    try {
      return URLDecoder.decode(paramString, "UTF-8");
    } catch (UnsupportedEncodingException unsupportedEncodingException) {
      return paramString;
    } 
  }
  
  public void showEvents() {
    this.mControllerFrame.setActiveTab(4);
  }
  
  public void showClockMonitoring() {
    this.mControllerFrame.showClockMonitoring();
  }
  
  public void addClockMonitoringObserver(IObserver paramIObserver) {
    this.mLogic.addClockMonitoringObserver(paramIObserver);
  }
  
  public void addClockMonitoringWindowListener(WindowListener paramWindowListener) {
    this.mControllerFrame.addClockMonitoringWindowListener(paramWindowListener);
  }
  
  public void addClockMonitoringComponentListener(ComponentListener paramComponentListener) {
    this.mControllerFrame.addClockMonitoringComponentListener(paramComponentListener);
  }
  
  public void clearClockEventsForAllDevices() {
    this.mLogic.clearClockEventsForAllDevices();
  }
  
  public void addFilteredNotificationByLogLevelListener(IObserver paramIObserver) {
    this.mControllerFrame.addFilteredNotificationByLogLevelListener(paramIObserver);
  }
  
  public void doShowSystemInformation(JFrame paramJFrame) {
    this.mControllerFrame.doShowSystemInformation(paramJFrame);
  }
  
  public void showTxRxLocked(JFrame paramJFrame) {
    JOptionPane.showOptionDialog(paramJFrame, new JLabel("<html>Transmitter and Receiver are locked.<br/>Unlock these devices to make changes.</html>", 0), "Warning", -1, -1, null, (Object[])new String[] { "Close" }, "default");
  }
  
  public void showRxOnlyUnlocked(JFrame paramJFrame, IDevice paramIDevice) {
    int i = JOptionPane.showOptionDialog(paramJFrame, new JLabel("<html>The Receiver is locked. Unlock the device to make changes.</html>", 0), "Warning", -1, -1, null, (Object[])new String[] { "Unlock Receiver", "Close" }, "default");
    if (i == 0)
      showLockDialogModal(paramJFrame, paramIDevice); 
  }
  
  public boolean showTxOnlyUnlocked(JFrame paramJFrame) {
    String str = this.mApplication.getPreferences().get("WARN_TX_LOCKED_SUBSCRIPTIONS", "warn");
    boolean bool = !"ignore".equals(str) ? true : false;
    if (bool) {
      JCheckBox jCheckBox = new JCheckBox("Don't ask me again.");
      JLabel jLabel = new JLabel("<html>Transmitter is locked.  Only subscriptions present at <br/>the time the transmitter was locked may be established.</html>", 0);
      Object[] arrayOfObject = { jLabel, jCheckBox };
      int i = JOptionPane.showOptionDialog(paramJFrame, arrayOfObject, "Warning", 2, -1, null, (Object[])new String[] { "Subscribe", "Cancel" }, "default");
      this.mApplication.getPreferences().put("WARN_TX_LOCKED_SUBSCRIPTIONS", !jCheckBox.isSelected() ? "warn" : "ignore");
      return (i == 0);
    } 
    return true;
  }
  
  public void showLockDialogModal(JFrame paramJFrame, IDevice paramIDevice) {
    if (!DeviceUtils.isLocked(paramIDevice)) {
      boolean bool = StaleAudioConnectionsDialog.checkStaleConnections(paramJFrame, this.mControllerModel.getUnfilteredDevices(), paramIDevice.getName(), this.mLogic.getRouterController(), this.mApplication.getSchedulableTimers());
      if (!bool)
        return; 
    } 
    try {
      ImageLibrary imageLibrary = this.mApplication.getImageLibrary();
      ThemedImage[] arrayOfThemedImage = new ThemedImage[2];
      arrayOfThemedImage[0] = imageLibrary.getImage("TICK_30");
      arrayOfThemedImage[1] = imageLibrary.getImage("CROSS_30");
      MillauLockDialog millauLockDialog = new MillauLockDialog(paramJFrame, arrayOfThemedImage, this.mLogicModel.getMillauLockClient(), (ISwingApplication)this.mApplication);
      millauLockDialog.localise(this.mBundle);
      millauLockDialog.setModal(true);
      millauLockDialog.setDevice(paramIDevice);
      millauLockDialog.pack();
      millauLockDialog.setLocationRelativeTo(paramJFrame);
      millauLockDialog.setVisible(true);
    } catch (AudinateException audinateException) {
      audinateException.printStackTrace();
    } 
  }
  
  private void updateAgentState() {
    if (this.mCmmClient == null)
      return; 
    if (this.mCmmClient.getConnectionState() != 2)
      return; 
    CmmState cmmState = this.mCmmClient.getSystemState();
    if (cmmState == null)
      return; 
    if (this.mAgentProcess != null)
      stopAgent(); 
    startAgent();
  }
  
  private long getPid() {
    return ProcessHandle.current().pid();
  }
  
  public void timerFired(ISchedulableTimer paramISchedulableTimer) {
    if (this.mAgentProcess != null)
      handleAgentTimer(); 
    if (this.mTranslatorProcess != null)
      handleTranslatorTimer(); 
    this.mApplication.getSchedulableTimers().createRelativeTimer(this, 1000L, "checkProcessesRunning");
  }
  
  private void handleAgentTimer() {
    if (!this.mAgentProcess.isAlive()) {
      this.mAgentProcess = null;
      if (this.mAgentRestartCount < 5) {
        this.mAgentRestartCount++;
        startAgent();
        this.mApplication.getDebugLog().log(7, null, "Agent restart...");
      } else {
        JOptionPane.showMessageDialog((Component)this.mControllerFrame, "Error: DanteControllerAgent can't be restarted.");
      } 
    } 
  }
  
  private void handleTranslatorTimer() {
    if (!this.mTranslatorProcess.isAlive()) {
      this.mTranslatorProcess = null;
      startTranslator();
      this.mApplication.getDebugLog().log(7, null, "Translator restart...");
    } 
  }
  
  private void startAgent() {
    if (this.mAgentProcess == null) {
      ArrayList<String> arrayList = new ArrayList();
      long l = getPid();
      if (this.mAgentPath == null) {
        JOptionPane.showMessageDialog(null, "Could not find DanteControllerAgent executable.");
      } else {
        arrayList.add(this.mAgentPath);
        arrayList.add("--pid=" + l);
        if (this.mAgentRemoteComponentPort == 0)
          this.mAgentRemoteComponentPort = this.mApplication.getJniEnvironment().createRemoteComponent(); 
        arrayList.add("--conmon-port=" + this.mAgentRemoteComponentPort);
        Boolean bool = Boolean.valueOf(this.mCmmClients.getSelection().isGlobal());
        ControllerConfig controllerConfig = getConfig();
        boolean bool1 = bool.booleanValue() ? false : controllerConfig.getConmonServerPort(false);
        arrayList.add("--unmanaged-conmon-port=" + bool1);
        for (String str1 : this.mPluginSearchPaths)
          arrayList.add("--library-path=" + str1); 
        this.mApplication.getDebugLog().log(6, null, "Launching " + (String)arrayList.stream().map(paramString -> paramString.contains(" ") ? ("'" + paramString + "'") : paramString).collect(Collectors.joining(" ")));
        ProcessBuilder processBuilder = new ProcessBuilder(arrayList);
        processBuilder.environment().put("LOG_LEVEL", Log.LEVELS[0]);
        String str = this.mApplication.getAgentLogFilename();
        if (str != null) {
          processBuilder.environment().put("LOG_LEVEL", Log.LEVELS[this.mConfig.getAgentLogLevel()]);
          processBuilder.environment().put("LOG_FILE", str);
        } 
        try {
          processBuilder.redirectOutput(ProcessBuilder.Redirect.PIPE);
          processBuilder.redirectErrorStream(true);
          this.mAgentProcess = processBuilder.start();
          AgentOutputThread agentOutputThread = new AgentOutputThread(this, this, this.mAgentProcess.getInputStream(), "OUTPUT");
          agentOutputThread.start();
        } catch (Exception exception) {
          JOptionPane.showMessageDialog(null, "Error starting agent: " + exception.toString());
        } 
      } 
    } 
  }
  
  public boolean stopAgent() {
    if (this.mAgentProcess != null) {
      this.mAgentProcess.destroyForcibly();
      this.mAgentProcess = null;
    } 
    if (this.mAgentRemoteComponentPort != 0) {
      this.mApplication.getJniEnvironment().destroyRemoteComponent(this.mAgentRemoteComponentPort);
      this.mAgentRemoteComponentPort = 0;
    } 
    return true;
  }
  
  private void startTranslator() {
    if (this.mTranslatorProcess != null || this.mTranslatorPath == null)
      return; 
    ArrayList<String> arrayList = new ArrayList();
    arrayList.add(this.mTranslatorPath);
    if (this.mArgoInterface == null || this.mArgoInterface.getIpAddress() == null || !this.mArgoInterface.isLinkUp()) {
      this.mApplication.getDebugLog().log(4, null, "Error starting the Argo translator process - Argo interface link is down or ip address is not available");
      return;
    } 
    arrayList.add("--argo-addr=" + this.mArgoInterface.getIpAddress());
    arrayList.add("--argo-port=" + this.mConfig.quicArgoPort());
    arrayList.add("--graphql-port=" + this.mConfig.graphQlPort());
    arrayList.add("--require-stdin");
    this.mApplication.getDebugLog().log(6, null, "Launching " + (String)arrayList.stream().map(paramString -> paramString.contains(" ") ? ("'" + paramString + "'") : paramString).collect(Collectors.joining(" ")));
    ProcessBuilder processBuilder = new ProcessBuilder(arrayList);
    try {
      processBuilder.redirectOutput(ProcessBuilder.Redirect.PIPE);
      processBuilder.redirectErrorStream(true);
      this.mTranslatorProcess = processBuilder.start();
      TranslatorOutputThread translatorOutputThread = new TranslatorOutputThread(this, this, this.mTranslatorProcess.getInputStream(), "OUTPUT");
      translatorOutputThread.start();
    } catch (Exception exception) {
      this.mApplication.getDebugLog().log(6, null, String.format("Error starting the Argo translator process: %s", new Object[] { exception.getMessage() }));
    } 
  }
  
  public int getWebsocketPort() {
    return this.mAgentWebsocketPort;
  }
  
  public int getWebserverPort() {
    return this.mAgentWebserverPort;
  }
  
  public void cmmOptionsChanged(ICmmClient paramICmmClient) {
    updateAgentState();
  }
  
  public void cmmStateChanged(ICmmClient paramICmmClient) {
    updateAgentState();
  }
  
  private void setCmmClient(ICmmClient paramICmmClient) {
    if (this.mCmmClient != null) {
      this.mCmmClient.removeCmmClientListener(this);
      this.mCmmClient = null;
    } 
    this.mCmmClient = paramICmmClient;
    if (this.mCmmClient != null)
      this.mCmmClient.addCmmClientListener(this); 
    updateAgentState();
  }
  
  public void setLegacyAssociatedDevicesShown(boolean paramBoolean) {
    this.mControllerModel.setLegacyAssociatedDevicesShown(paramBoolean);
  }
  
  public void localise(ResourceBundle paramResourceBundle) {
    if (paramResourceBundle != null)
      this.mBundle = paramResourceBundle; 
    if (this.mControllerFrame != null)
      this.mControllerFrame.localise(paramResourceBundle); 
    if (this.mDeviceFrames != null)
      this.mDeviceFrames.localise(paramResourceBundle); 
  }
  
  private void handleInterfaceUpdateEvent(ICmmClient paramICmmClient) {
    CmmConfig cmmConfig = paramICmmClient.getSystemState().getCurrentConfig();
    NetworkInterface networkInterface = this.mArgoInterface;
    if (cmmConfig.numInterfaces() > 0) {
      CmmInterface cmmInterface = cmmConfig.interfaceAtIndex(0);
      this.mArgoInterface = this.mApplication.getNetworkInterfaceManager().interfaceWithName(cmmInterface.getName());
      if (this.mArgoInterface == null)
        return; 
    } else {
      return;
    } 
    if (networkInterface != null && networkInterface.getIpAddress() == this.mArgoInterface.getIpAddress() && this.mTranslatorProcess != null && this.mArgoInterface.isLinkUp())
      return; 
    if (this.mTranslatorProcess != null)
      this.mTranslatorProcess.destroy(); 
    if (this.mArgoInterface.isLinkUp())
      startTranslator(); 
  }
}
